package ch.uzh.ifi.ddis.ifp.streams;

/*
 * #%L
 * Esper implementation of Streams Nodes
 * %%
 * Copyright (C) 2013 University of Zurich
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * #L%
 */

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.w3c.dom.Node;

/**
 * 
 * @author Thomas Scharrenbach
 * @version 0.2.4
 * @since 0.2.4
 * 
 */
public class StatementBeanFactory {

	private static final Logger _log = LoggerFactory
			.getLogger(StatementBeanFactory.class);

	public StatementBean createStatementBean(Node esperStatementNode)
			throws Exception {
		final String esperStatement = esperStatementNode.getTextContent();
		_log.debug("Adding statement for Esper: {}", esperStatement);
		if (esperStatement == null) {
			_log.error("Empty Esper statement node.");
			throw new Exception(
					"If specified, Esper statement must not be empty!");
		}
		//
		else {
			final StatementBean statementBean = new StatementBean();
			statementBean.setEsperStatement(esperStatement.trim());

			if (esperStatementNode.hasAttributes()) {
				final Node outputAttr = esperStatementNode.getAttributes()
						.getNamedItem("output");
				if (outputAttr != null) {
					// Note: _queue is not yet set. We cannot check whether
					// a queue actually exists.
					final String output = outputAttr.getTextContent().trim();
					statementBean.setOutput(output);
				}

				// Add the statement's name if specified.
				final Node nameAttr = esperStatementNode.getAttributes()
						.getNamedItem("name");
				if (nameAttr != null) {
					statementBean.setName(nameAttr.getTextContent().trim());
				}
			}
			return statementBean;
		}

	}

}
